@@ -1,6 +1,4 @@
 import uuid
-import struct
-import boto3
 import apsw
 
 
@@ -14,12 +12,8 @@ class S3VFS(apsw.VFS):
     def xAccess(self, pathname, flags):
         if flags == apsw.mapping_access["SQLITE_ACCESS_EXISTS"]:
             return any(self._bucket.objects.filter(Prefix=pathname + '/'))
-        elif flags == apsw.mapping_access["SQLITE_ACCESS_READWRITE"]:
-            # something sometihng ACLs
-            return True
-        elif flags == apsw.mapping_access["SQLITE_ACCESS_READ"]:
-            # something something ACLs
-            return True
+
+        return True
 
     def xFullPathname(self, filename):
         return filename
